@@ -1,6 +1,8 @@
-        package HTTP::Exception::Loader;
+package HTTP::Exception::Loader;
 
 use strict;
+use warnings;
+
 use HTTP::Exception::Base;
 use HTTP::Exception::1XX;
 use HTTP::Exception::2XX;
@@ -9,7 +11,7 @@ use HTTP::Exception::4XX;
 use HTTP::Exception::5XX;
 use HTTP::Status;
 
-our $VERSION = '0.04';
+our $VERSION = '0.04001';
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
 ################################################################################
@@ -71,8 +73,12 @@ sub _make_exceptions {
         ~;
     }
 
-    #print STDOUT $code;
-    eval $code;
+    # RT https://rt.cpan.org/Ticket/Display.html?id=79021
+    # silence warnings about "subroutine redefined" in a mod_perl environment
+    {
+        no warnings 'redefine';
+        eval $code;
+    }
     return @exception_classes;
 }
 
@@ -120,7 +126,7 @@ HTTP::Exception::Loader - Creates HTTP::Exception subclasses
 
 =head1 VERSION
 
-0.04
+0.04001
 
 =head1 DESCRIPTION
 
